==> alg-common-1.22.1-20191009.085457-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityrecommend/SelectPoolInfo.java <==
package cn.com.duiba.nezha.alg.common.model.activityrecommend;

/**
 * @author lijingzhe
 * @description 优选bean
 * @date 2019/8/22
 */
public class SelectPoolInfo {
    /**
     * 收益
     */
    private double reward;
    /**
     * 活动类型
     */
    private long activityType;
    /**
     * 索引
     */
    private int index;
    /**
     * 活动id
     */
    private long activityId;
    /**
     * 转化分
     */
    private double changeScore;
    /**
     * 广告位每pv消耗
     */
    private double hrpm;
    /**
     * 媒体每pv消耗
     */
    private double arpm;
    /**
     * 全局每pv消耗
     */
    private double grpm;
    /**
     * 活动访问pv
     */
    private double request;
    /**
     * v4.0 皮肤含有ops或vm新活动 1;否则老活动 0
     */
    private int subType;
    /**
     * 是否是优质活动
     */
    private boolean excellent;
    /**
     * 归一化分数
     */
    private double scores;

    public double getReward() {
        return reward;
    }

    public void setReward(double reward) {
        this.reward = reward;
    }

    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public int getIndex() {
        return index;
    }

    public void setIndex(int index) {
        this.index = index;
    }

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public double getHrpm() {
        return hrpm;
    }

    public void setHrpm(double hrpm) {
        this.hrpm = hrpm;
    }

    public double getArpm() {
        return arpm;
    }

    public void setArpm(double arpm) {
        this.arpm = arpm;
    }

    public double getGrpm() {
        return grpm;
    }

    public void setGrpm(double grpm) {
        this.grpm = grpm;
    }

    public double getRequest() {
        return request;
    }

    public void setRequest(double request) {
        this.request = request;
    }

    public boolean isExcellent() {
        return excellent;
    }

    public void setExcellent(boolean excellent) {
        this.excellent = excellent;
    }

    public double getScores() {
        return scores;
    }

    public void setScores(double scores) {
        this.scores = scores;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }
}

==> alg-common-2.7.1-20191107.090048-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityrecommend/SelectPoolInfo.java <==
package cn.com.duiba.nezha.alg.common.model.activityrecommend;

/**
 * @author lijingzhe
 * @description 优选bean
 * @date 2019/8/22
 */
public class SelectPoolInfo {
    /**
     * 收益
     */
    private double reward;
    /**
     * 活动类型
     */
    private long activityType;
    /**
     * 索引
     */
    private int index;
    /**
     * 活动id
     */
    private long activityId;
    /**
     * 转化分
     */
    private double changeScore;
    /**
     * 广告位每pv消耗
     */
    private double hrpm;
    /**
     * 媒体每pv消耗
     */
    private double arpm;
    /**
     * 全局每pv消耗
     */
    private double grpm;
    /**
     * 活动访问pv
     */
    private double request;
    /**
     * v4.0 皮肤含有ops或vm新活动 1;否则老活动 0
     */
    private int subType;
    /**
     * 是否是优质活动
     */
    private boolean excellent;
    /**
     * 归一化分数
     */
    private double scores;
    /**
     * 广告位cvr
     */
    private double cvrBias;

    public double getReward() {
        return reward;
    }

    public void setReward(double reward) {
        this.reward = reward;
    }

    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public int getIndex() {
        return index;
    }

    public void setIndex(int index) {
        this.index = index;
    }

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public double getHrpm() {
        return hrpm;
    }

    public void setHrpm(double hrpm) {
        this.hrpm = hrpm;
    }

    public double getArpm() {
        return arpm;
    }

    public void setArpm(double arpm) {
        this.arpm = arpm;
    }

    public double getGrpm() {
        return grpm;
    }

    public void setGrpm(double grpm) {
        this.grpm = grpm;
    }

    public double getRequest() {
        return request;
    }

    public void setRequest(double request) {
        this.request = request;
    }

    public boolean isExcellent() {
        return excellent;
    }

    public void setExcellent(boolean excellent) {
        this.excellent = excellent;
    }

    public double getScores() {
        return scores;
    }

    public void setScores(double scores) {
        this.scores = scores;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }

    public double getCvrBias() {
        return cvrBias;
    }

    public void setCvrBias(double cvrBias) {
        this.cvrBias = cvrBias;
    }
}
